@@ -87,7 +87,7 @@ def install_packages(url, verbose=True):
 
     from tools import rcode
     if verbose == True:
-        print("Installing %s " % filename)
+        print("Installing %s from %s" % (url, filename))
 
     rcode("""install.packages("%s", repos=NULL)""" % filename)
 
