@@ -102,18 +102,91 @@ def Rnames2attributes(f):
     """
     def wrap(*args, **kargs):
         res = f(*args, **kargs)
-        try:
-            for name in res.names:
-                setattr(res, name, res.rx2(name))
-        except:
-            # for the case where nothing is returned
-            pass
+        res = setAttributes(res)
+        #try:
+        #    for name in res.names:
+        #        setattr(res, name, res.rx2(name))
+        #except:
+        #    # for the case where nothing is returned
+        #    pass
         return res
     wrap.__name__ = f.__name__
     return wrap
 
 
 
+def setAttributes(res):
+    """A recursive function to set the attributes of a ListVector R object
+
+
+    a Robject that belong to the ListVector class can name its field. Each field
+    can be itself a ListVector. For example::
+
+        >>> listVector = rtools.rcode("m = list(a=1, b=list(c=1, d=2))")
+
+    You can now access to the field a as follows::
+
+        listVector.rx2('a')
+
+    and to *c*::
+
+        listVector.rx2('b').rx2('c')
+
+    This function build READ ONLY attributes recursively::
+
+        listVector2 = setAttributes(listVector)  
+        listVector2.b.c
+        listVector2.a
+
+    It works by looking at listVector.names to find the field.
+
+    In principle, simply checking that names is NULL should suffice to stop the
+    recursion, however, rpy2 seems buggy: for instance if a field is a matrix,
+    the names returned is actually a combination of colnames and rownames. Hence raising a
+    message error since we expect NULL (as in a pure R session).
+
+    If names is not NULL, it should be a list of names so it should be a
+    StrVector R object. so, the fix is to check if the names is NULL or its type
+    is different from StrVector.
+
+    """
+    #print( "Entering setAttributs %s" % res.names)
+    #print("----------------------")
+    import rpy2.robjects
+
+    # if the object is NULL/None, just return it
+    if res == rpy2.rinterface.NULL or res == None:
+        return res
+    # if it is a class, don't do anything, just return it
+    elif type(res)==rpy2.robjects.methods.RS4:
+        # do not deal with RS4 although, we could parse them with S4Class ?
+        return res
+    # if it has no name in it, there will be no more recursion, so return it
+    #elif 'name' not in dir(res):
+    #    return res 
+    # if names if defined but null, return it
+    elif res.names == rpy2.rinterface.NULL:
+        # if null, nothing to be done anymore
+        return res
+    # if it has names, it should be a StrVector otherwise, we dont know what to
+    # do with it
+    elif type(res.names) != rpy2.robjects.vectors.StrVector:
+        # sometimes, names is not NULL (altough it is in a pure R session)
+        # so, let us check that names is not a vector or empty vector (if not NULL) 
+        return res
+    # it should be a non empty list
+    elif len(res.names) and res.names[0] == '':
+        return res
+    # if we finally enter here, we have a list of names to go through.
+    else:
+        for name in res.names:
+            #print("dealing with %s" % name)
+            setattr(res, name, setAttributes(res.rx2(name)))
+    return res
+
+
+
+
 class RManualToDocString(object):
     """Reads R manual and convert to Sphinx doc string.
 
