@@ -1,6 +1,13 @@
 from rtools.package import *
 
 
+def test_install_package():
+    url = "http://www.ebi.ac.uk/saezrodriguez/cno/downloads/MEIGOR_0.99.3_svn2719.tar.gz"
+    install_packages(url)
+
+
+def _test_biocLite():
+    biocLite("CellNOptR")
 
 def test_Rpackage():
 
